Class: Aws::MedicalImaging::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MedicalImaging::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-medicalimaging/client.rb,
sig/client.rbs
Overview
An API client for MedicalImaging. To construct a client, you need to configure a :region and :credentials.
client = Aws::MedicalImaging::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CopyImageSetResponseSuccess, _CreateDatastoreResponseSuccess, _DeleteDatastoreResponseSuccess, _DeleteImageSetResponseSuccess, _GetDICOMImportJobResponseSuccess, _GetDatastoreResponseSuccess, _GetImageFrameResponseSuccess, _GetImageSetMetadataResponseSuccess, _GetImageSetResponseSuccess, _ListDICOMImportJobsResponseSuccess, _ListDatastoresResponseSuccess, _ListImageSetVersionsResponseSuccess, _ListTagsForResourceResponseSuccess, _SearchImageSetsResponseSuccess, _StartDICOMImportJobResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateImageSetMetadataResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#copy_image_set(params = {}) ⇒ Types::CopyImageSetResponse
Copy an image set.
-
#create_datastore(params = {}) ⇒ Types::CreateDatastoreResponse
Create a data store.
-
#delete_datastore(params = {}) ⇒ Types::DeleteDatastoreResponse
Delete a data store.
-
#delete_image_set(params = {}) ⇒ Types::DeleteImageSetResponse
Delete an image set.
-
#get_datastore(params = {}) ⇒ Types::GetDatastoreResponse
Get data store properties.
-
#get_dicom_import_job(params = {}) ⇒ Types::GetDICOMImportJobResponse
Get the import job properties to learn more about the job or job progress.
-
#get_image_frame(params = {}) ⇒ Types::GetImageFrameResponse
Get an image frame (pixel data) for an image set.
-
#get_image_set(params = {}) ⇒ Types::GetImageSetResponse
Get image set properties.
-
#get_image_set_metadata(params = {}) ⇒ Types::GetImageSetMetadataResponse
Get metadata attributes for an image set.
-
#list_datastores(params = {}) ⇒ Types::ListDatastoresResponse
List data stores.
-
#list_dicom_import_jobs(params = {}) ⇒ Types::ListDICOMImportJobsResponse
List import jobs created for a specific data store.
-
#list_image_set_versions(params = {}) ⇒ Types::ListImageSetVersionsResponse
List image set versions.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a medical imaging resource.
-
#search_image_sets(params = {}) ⇒ Types::SearchImageSetsResponse
Search image sets based on defined input attributes.
-
#start_dicom_import_job(params = {}) ⇒ Types::StartDICOMImportJobResponse
Start importing bulk data into an
ACTIVEdata store. -
#tag_resource(params = {}) ⇒ Struct
Adds a user-specifed key and value tag to a medical imaging resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a medical imaging resource.
-
#update_image_set_metadata(params = {}) ⇒ Types::UpdateImageSetMetadataResponse
Update image set metadata attributes.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1457 1458 1459 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1457 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1460 1461 1462 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1460 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1430 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MedicalImaging') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-medicalimaging' context[:gem_version] = '1.50.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_image_set(params = {}) ⇒ Types::CopyImageSetResponse
Copy an image set.
88 |
# File 'sig/client.rbs', line 88
def copy_image_set: (
|
#create_datastore(params = {}) ⇒ Types::CreateDatastoreResponse
Create a data store.
114 |
# File 'sig/client.rbs', line 114
def create_datastore: (
|
#delete_datastore(params = {}) ⇒ Types::DeleteDatastoreResponse
Delete a data store.
130 |
# File 'sig/client.rbs', line 130
def delete_datastore: (
|
#delete_image_set(params = {}) ⇒ Types::DeleteImageSetResponse
Delete an image set.
143 |
# File 'sig/client.rbs', line 143
def delete_image_set: (
|
#get_datastore(params = {}) ⇒ Types::GetDatastoreResponse
Get data store properties.
165 |
# File 'sig/client.rbs', line 165
def get_datastore: (
|
#get_dicom_import_job(params = {}) ⇒ Types::GetDICOMImportJobResponse
Get the import job properties to learn more about the job or job progress.
jobStatus refers to the execution of the import job. Therefore,
an import job can return a jobStatus as COMPLETED even if
validation issues are discovered during the import process. If a
jobStatus returns as COMPLETED, we still recommend you review the
output manifests written to S3, as they provide details on the success
or failure of individual P10 object imports.
154 |
# File 'sig/client.rbs', line 154
def get_dicom_import_job: (
|
#get_image_frame(params = {}) ⇒ Types::GetImageFrameResponse
Get an image frame (pixel data) for an image set.
176 |
# File 'sig/client.rbs', line 176
def get_image_frame: (
|
#get_image_set(params = {}) ⇒ Types::GetImageSetResponse
Get image set properties.
203 |
# File 'sig/client.rbs', line 203
def get_image_set: (
|
#get_image_set_metadata(params = {}) ⇒ Types::GetImageSetMetadataResponse
Get metadata attributes for an image set.
217 |
# File 'sig/client.rbs', line 217
def get_image_set_metadata: (
|
#list_datastores(params = {}) ⇒ Types::ListDatastoresResponse
List data stores.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
244 |
# File 'sig/client.rbs', line 244
def list_datastores: (
|
#list_dicom_import_jobs(params = {}) ⇒ Types::ListDICOMImportJobsResponse
List import jobs created for a specific data store.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
230 |
# File 'sig/client.rbs', line 230
def list_dicom_import_jobs: (
|
#list_image_set_versions(params = {}) ⇒ Types::ListImageSetVersionsResponse
List image set versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
257 |
# File 'sig/client.rbs', line 257
def list_image_set_versions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a medical imaging resource.
270 |
# File 'sig/client.rbs', line 270
def list_tags_for_resource: (
|
#search_image_sets(params = {}) ⇒ Types::SearchImageSetsResponse
Search image sets based on defined input attributes.
SearchImageSets accepts a single search query parameter and returns
a paginated response of all image sets that have the matching
criteria. All date range queries must be input as (lowerBound, upperBound).
By default, SearchImageSets uses the updatedAt field for sorting
in descending order from newest to oldest.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
282 |
# File 'sig/client.rbs', line 282
def search_image_sets: (
|
#start_dicom_import_job(params = {}) ⇒ Types::StartDICOMImportJobResponse
Start importing bulk data into an ACTIVE data store. The import job
imports DICOM P10 files or enhances existing DICOM files with JSON
metadata. The importConfiguration parameter specifies the import
type. The data is found in the S3 prefix specified by the inputS3Uri
parameter. The import job stores processing results in the file
specified by the outputS3Uri parameter.
324 |
# File 'sig/client.rbs', line 324
def start_dicom_import_job: (
|
#tag_resource(params = {}) ⇒ Struct
Adds a user-specifed key and value tag to a medical imaging resource.
350 |
# File 'sig/client.rbs', line 350
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a medical imaging resource.
360 |
# File 'sig/client.rbs', line 360
def untag_resource: (
|
#update_image_set_metadata(params = {}) ⇒ Types::UpdateImageSetMetadataResponse
Update image set metadata attributes.
378 |
# File 'sig/client.rbs', line 378
def update_image_set_metadata: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1450 1451 1452 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1450 def waiter_names [] end |