Class: Aws::MedicalImaging::Types::CopyImageSetRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medicalimaging/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_image_set_informationTypes::CopyImageSetInformation

Copy image set information.



167
168
169
170
171
172
173
174
175
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167

class CopyImageSetRequest < Struct.new(
  :datastore_id,
  :source_image_set_id,
  :copy_image_set_information,
  :force,
  :promote_to_primary)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_idString

The data store identifier.

Returns:

  • (String)


167
168
169
170
171
172
173
174
175
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167

class CopyImageSetRequest < Struct.new(
  :datastore_id,
  :source_image_set_id,
  :copy_image_set_information,
  :force,
  :promote_to_primary)
  SENSITIVE = []
  include Aws::Structure
end

#forceBoolean

Providing this parameter will force completion of the ‘CopyImageSet` operation, even if there are inconsistent Patient, Study, and/or Series level metadata elements between the `sourceImageSet` and `destinationImageSet`.

Returns:

  • (Boolean)


167
168
169
170
171
172
173
174
175
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167

class CopyImageSetRequest < Struct.new(
  :datastore_id,
  :source_image_set_id,
  :copy_image_set_information,
  :force,
  :promote_to_primary)
  SENSITIVE = []
  include Aws::Structure
end

#promote_to_primaryBoolean

Providing this parameter will configure the ‘CopyImageSet` operation to promote the given image set to the primary DICOM hierarchy. If successful, a new primary image set ID will be returned as the destination image set.

Returns:

  • (Boolean)


167
168
169
170
171
172
173
174
175
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167

class CopyImageSetRequest < Struct.new(
  :datastore_id,
  :source_image_set_id,
  :copy_image_set_information,
  :force,
  :promote_to_primary)
  SENSITIVE = []
  include Aws::Structure
end

#source_image_set_idString

The source image set identifier.

Returns:

  • (String)


167
168
169
170
171
172
173
174
175
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167

class CopyImageSetRequest < Struct.new(
  :datastore_id,
  :source_image_set_id,
  :copy_image_set_information,
  :force,
  :promote_to_primary)
  SENSITIVE = []
  include Aws::Structure
end