Class: Aws::MedicalImaging::Types::DICOMImportJobProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::MedicalImaging::Types::DICOMImportJobProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medicalimaging/types.rb
Overview
Properties of the import job.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) that grants permissions to access medical imaging resources.
-
#datastore_id ⇒ String
The data store identifier.
-
#ended_at ⇒ Time
The timestamp for when the import job was ended.
-
#import_configuration ⇒ Types::ImportConfiguration
The object containing ‘DicomJsonMetadataImportConfiguration`.
-
#input_s3_uri ⇒ String
The input prefix path for the S3 bucket that contains the DICOM P10 files to be imported.
-
#job_id ⇒ String
The import job identifier.
-
#job_name ⇒ String
The import job name.
-
#job_status ⇒ String
The filters for listing import jobs based on status.
-
#message ⇒ String
The error message thrown if an import job fails.
-
#output_s3_uri ⇒ String
The output prefix of the S3 bucket to upload the results of the DICOM import job.
-
#submitted_at ⇒ Time
The timestamp for when the import job was submitted.
Instance Attribute Details
#data_access_role_arn ⇒ String
The Amazon Resource Name (ARN) that grants permissions to access medical imaging resources.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#datastore_id ⇒ String
The data store identifier.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#ended_at ⇒ Time
The timestamp for when the import job was ended.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#import_configuration ⇒ Types::ImportConfiguration
The object containing ‘DicomJsonMetadataImportConfiguration`.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#input_s3_uri ⇒ String
The input prefix path for the S3 bucket that contains the DICOM P10 files to be imported.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#job_id ⇒ String
The import job identifier.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#job_name ⇒ String
The import job name.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#job_status ⇒ String
The filters for listing import jobs based on status.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message thrown if an import job fails.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#output_s3_uri ⇒ String
The output prefix of the S3 bucket to upload the results of the DICOM import job.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |
#submitted_at ⇒ Time
The timestamp for when the import job was submitted.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 372 class DICOMImportJobProperties < Struct.new( :job_id, :job_name, :job_status, :datastore_id, :data_access_role_arn, :ended_at, :submitted_at, :input_s3_uri, :output_s3_uri, :message, :import_configuration) SENSITIVE = [] include Aws::Structure end |