Class: Aws::MedicalImaging::Types::DatastoreProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::MedicalImaging::Types::DatastoreProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medicalimaging/types.rb
Overview
The properties associated with the data store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the data store was created.
-
#datastore_arn ⇒ String
The Amazon Resource Name (ARN) for the data store.
-
#datastore_id ⇒ String
The data store identifier.
-
#datastore_name ⇒ String
The data store name.
-
#datastore_status ⇒ String
The data store status.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) assigned to the Key Management Service (KMS) key for accessing encrypted data.
-
#lambda_authorizer_arn ⇒ String
The ARN of the authorizer’s Lambda function.
-
#lossless_storage_format ⇒ String
The datastore’s lossless storage format.
-
#updated_at ⇒ Time
The timestamp when the data store was last updated.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the data store was created.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#datastore_arn ⇒ String
The Amazon Resource Name (ARN) for the data store.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#datastore_id ⇒ String
The data store identifier.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#datastore_name ⇒ String
The data store name.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#datastore_status ⇒ String
The data store status.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) assigned to the Key Management Service (KMS) key for accessing encrypted data.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#lambda_authorizer_arn ⇒ String
The ARN of the authorizer’s Lambda function.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#lossless_storage_format ⇒ String
The datastore’s lossless storage format.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the data store was last updated.
608 609 610 611 612 613 614 615 616 617 618 619 620 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 608 class DatastoreProperties < Struct.new( :datastore_id, :datastore_name, :datastore_status, :kms_key_arn, :lambda_authorizer_arn, :lossless_storage_format, :datastore_arn, :created_at, :updated_at) SENSITIVE = [] include Aws::Structure end |