Class: Aws::MedicalImaging::Types::GetImageFrameResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MedicalImaging::Types::GetImageFrameResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medicalimaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#content_type ⇒ String
The format in which the image frame information is returned to the customer.
-
#image_frame_blob ⇒ IO
The blob containing the aggregated image frame information.
Instance Attribute Details
#content_type ⇒ String
The format in which the image frame information is returned to the customer. Default is ‘application/octet-stream`.
<note markdown=“1”> * If the stored transfer syntax is ‘1.2.840.10008.1.2.1`, the
returned `contentType` is `application/octet-stream`.
^
* If the stored transfer syntax is `1.2.840.10008.1.2.4.50`, the
returned `contentType` is `image/jpeg`.
^
* If the stored transfer syntax is `1.2.840.10008.1.2.4.91`, the
returned `contentType` is `image/j2c`.
^
* If the stored transfer syntax is MPEG2, `1.2.840.10008.1.2.4.100`,
`1.2.840.10008.1.2.4.100.1`, `1.2.840.10008.1.2.4.101`, or
`1.2.840.10008.1.2.4.101.1`, the returned `contentType` is
`video/mpeg`.
^
* If the stored transfer syntax is MPEG-4 AVC/H.264, UID
`1.2.840.10008.1.2.4.102`, `1.2.840.10008.1.2.4.102.1`,
`1.2.840.10008.1.2.4.103`, `1.2.840.10008.1.2.4.103.1`,
`1.2.840.10008.1.2.4.104`, `1.2.840.10008.1.2.4.104.1`,
`1.2.840.10008.1.2.4.105`, `1.2.840.10008.1.2.4.105.1`,
`1.2.840.10008.1.2.4.106`, or `1.2.840.10008.1.2.4.106.1`, the
returned `contentType` is `video/mp4`.
^
* If the stored transfer syntax is HEVC/H.265, UID
`1.2.840.10008.1.2.4.107` or `1.2.840.10008.1.2.4.108`, the
returned `contentType` is `video/H256`.
^
* If the stored transfer syntax is `1.2.840.10008.1.2.4.202` or if
the stored transfer syntax is *missing*, the returned
`contentType` is `image/jph`.
^
* If the stored transfer syntax is `1.2.840.10008.1.2.4.203`, the
returned contentType is `image/jphc`.
-
If the stored transfer syntax is ‘1.2.840.10008.1.2.4.112` the returned `contentType` is `image/jxl`.
</note>
912 913 914 915 916 917 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 912 class GetImageFrameResponse < Struct.new( :image_frame_blob, :content_type) SENSITIVE = [] include Aws::Structure end |
#image_frame_blob ⇒ IO
The blob containing the aggregated image frame information.
912 913 914 915 916 917 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 912 class GetImageFrameResponse < Struct.new( :image_frame_blob, :content_type) SENSITIVE = [] include Aws::Structure end |