Class: Aws::MedicalImaging::Types::GetImageSetMetadataResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medicalimaging/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#content_encodingString

The compression format in which image set metadata attributes are returned.

Returns:

  • (String)


958
959
960
961
962
963
964
# File 'lib/aws-sdk-medicalimaging/types.rb', line 958

class GetImageSetMetadataResponse < Struct.new(
  :image_set_metadata_blob,
  :content_type,
  :content_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#content_typeString

The format in which the study metadata is returned to the customer. Default is ‘text/plain`.

Returns:

  • (String)


958
959
960
961
962
963
964
# File 'lib/aws-sdk-medicalimaging/types.rb', line 958

class GetImageSetMetadataResponse < Struct.new(
  :image_set_metadata_blob,
  :content_type,
  :content_encoding)
  SENSITIVE = []
  include Aws::Structure
end

#image_set_metadata_blobIO

The blob containing the aggregated metadata information for the image set.

Returns:

  • (IO)


958
959
960
961
962
963
964
# File 'lib/aws-sdk-medicalimaging/types.rb', line 958

class GetImageSetMetadataResponse < Struct.new(
  :image_set_metadata_blob,
  :content_type,
  :content_encoding)
  SENSITIVE = []
  include Aws::Structure
end