Class: Aws::MedicalImaging::Types::GetImageSetResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-medicalimaging/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_atTime

The timestamp when image set properties were created.

Returns:

  • (Time)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#datastore_idString

The data store identifier.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#deleted_atTime

The timestamp when the image set properties were deleted.

Returns:

  • (Time)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#image_set_arnString

The Amazon Resource Name (ARN) assigned to the image set.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#image_set_idString

The image set identifier.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#image_set_stateString

The image set state.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#image_set_workflow_statusString

The image set workflow status.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#is_primaryBoolean

The flag to determine whether the image set is primary or not.

Returns:

  • (Boolean)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#last_accessed_atTime

When the image set was last accessed.

Returns:

  • (Time)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

The error message thrown if an image set action fails.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#overridesTypes::Overrides

This object contains the details of any overrides used while creating a specific image set version. If an image set was copied or updated using the ‘force` flag, this object will contain the `forced` flag.

Returns:



1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#storage_tierString

The storage tier of the image set.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The timestamp when image set properties were updated.

Returns:

  • (Time)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

The image set version identifier.

Returns:

  • (String)


1049
1050
1051
1052
1053
1054
1055
1056
1057
1058
1059
1060
1061
1062
1063
1064
1065
1066
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049

class GetImageSetResponse < Struct.new(
  :datastore_id,
  :image_set_id,
  :version_id,
  :image_set_state,
  :image_set_workflow_status,
  :created_at,
  :updated_at,
  :deleted_at,
  :message,
  :image_set_arn,
  :overrides,
  :is_primary,
  :last_accessed_at,
  :storage_tier)
  SENSITIVE = []
  include Aws::Structure
end