Class: Aws::MedicalImaging::Types::ImageSetProperties
- Inherits:
-
Struct
- Object
- Struct
- Aws::MedicalImaging::Types::ImageSetProperties
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medicalimaging/types.rb
Overview
The image set properties.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when the image set properties were created.
-
#deleted_at ⇒ Time
The timestamp when the image set properties were deleted.
-
#image_set_id ⇒ String
The image set identifier.
-
#image_set_state ⇒ String
The image set state.
-
#image_set_workflow_status ⇒ String
The image set workflow status.
-
#is_primary ⇒ Boolean
The flag to determine whether the image set is primary or not.
-
#message ⇒ String
The error message thrown if an image set action fails.
-
#overrides ⇒ Types::Overrides
Contains details on overrides used when creating the returned version of an image set.
-
#updated_at ⇒ Time
The timestamp when the image set properties were updated.
-
#version_id ⇒ String
The image set version identifier.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when the image set properties were created.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#deleted_at ⇒ Time
The timestamp when the image set properties were deleted.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#image_set_id ⇒ String
The image set identifier.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#image_set_state ⇒ String
The image set state.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#image_set_workflow_status ⇒ String
The image set workflow status.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#is_primary ⇒ Boolean
The flag to determine whether the image set is primary or not.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message thrown if an image set action fails.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#overrides ⇒ Types::Overrides
Contains details on overrides used when creating the returned version of an image set. For example, if ‘forced` exists, the `forced` flag was used when creating the image set.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when the image set properties were updated.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The image set version identifier.
1128 1129 1130 1131 1132 1133 1134 1135 1136 1137 1138 1139 1140 1141 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1128 class ImageSetProperties < Struct.new( :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :overrides, :is_primary) SENSITIVE = [] include Aws::Structure end |