Class: Aws::MedicalImaging::Types::UpdateImageSetMetadataRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MedicalImaging::Types::UpdateImageSetMetadataRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medicalimaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#datastore_id ⇒ String
The data store identifier.
-
#force ⇒ Boolean
Setting this flag will force the ‘UpdateImageSetMetadata` operation for the following attributes:.
-
#image_set_id ⇒ String
The image set identifier.
-
#include_study_image_sets ⇒ Boolean
Flag to apply the metadata updates to all image sets in the same Study as the requested image set ID.
-
#latest_version_id ⇒ String
The latest image set version identifier.
-
#update_image_set_metadata_updates ⇒ Types::MetadataUpdates
Update image set metadata updates.
Instance Attribute Details
#datastore_id ⇒ String
The data store identifier.
1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1848 class UpdateImageSetMetadataRequest < Struct.new( :datastore_id, :image_set_id, :latest_version_id, :force, :include_study_image_sets, :update_image_set_metadata_updates) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Setting this flag will force the ‘UpdateImageSetMetadata` operation for the following attributes:
-
‘Tag.StudyInstanceUID`, `Tag.SeriesInstanceUID`, `Tag.SOPInstanceUID`, and `Tag.StudyID`
-
Adding, removing, or updating private tags for an individual SOP Instance
1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1848 class UpdateImageSetMetadataRequest < Struct.new( :datastore_id, :image_set_id, :latest_version_id, :force, :include_study_image_sets, :update_image_set_metadata_updates) SENSITIVE = [] include Aws::Structure end |
#image_set_id ⇒ String
The image set identifier.
1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1848 class UpdateImageSetMetadataRequest < Struct.new( :datastore_id, :image_set_id, :latest_version_id, :force, :include_study_image_sets, :update_image_set_metadata_updates) SENSITIVE = [] include Aws::Structure end |
#include_study_image_sets ⇒ Boolean
Flag to apply the metadata updates to all image sets in the same Study as the requested image set ID.
1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1848 class UpdateImageSetMetadataRequest < Struct.new( :datastore_id, :image_set_id, :latest_version_id, :force, :include_study_image_sets, :update_image_set_metadata_updates) SENSITIVE = [] include Aws::Structure end |
#latest_version_id ⇒ String
The latest image set version identifier.
1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1848 class UpdateImageSetMetadataRequest < Struct.new( :datastore_id, :image_set_id, :latest_version_id, :force, :include_study_image_sets, :update_image_set_metadata_updates) SENSITIVE = [] include Aws::Structure end |
#update_image_set_metadata_updates ⇒ Types::MetadataUpdates
Update image set metadata updates.
1848 1849 1850 1851 1852 1853 1854 1855 1856 1857 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1848 class UpdateImageSetMetadataRequest < Struct.new( :datastore_id, :image_set_id, :latest_version_id, :force, :include_study_image_sets, :update_image_set_metadata_updates) SENSITIVE = [] include Aws::Structure end |