Class: Aws::MedicalImaging::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::MedicalImaging::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-medicalimaging/client.rb
Overview
An API client for MedicalImaging. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::MedicalImaging::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#copy_image_set(params = {}) ⇒ Types::CopyImageSetResponse
Copy an image set.
-
#create_datastore(params = {}) ⇒ Types::CreateDatastoreResponse
Create a data store.
-
#delete_datastore(params = {}) ⇒ Types::DeleteDatastoreResponse
Delete a data store.
-
#delete_image_set(params = {}) ⇒ Types::DeleteImageSetResponse
Delete an image set.
-
#get_datastore(params = {}) ⇒ Types::GetDatastoreResponse
Get data store properties.
-
#get_dicom_import_job(params = {}) ⇒ Types::GetDICOMImportJobResponse
Get the import job properties to learn more about the job or job progress.
-
#get_image_frame(params = {}) ⇒ Types::GetImageFrameResponse
Get an image frame (pixel data) for an image set.
-
#get_image_set(params = {}) ⇒ Types::GetImageSetResponse
Get image set properties.
-
#get_image_set_metadata(params = {}) ⇒ Types::GetImageSetMetadataResponse
Get metadata attributes for an image set.
-
#list_datastores(params = {}) ⇒ Types::ListDatastoresResponse
List data stores.
-
#list_dicom_import_jobs(params = {}) ⇒ Types::ListDICOMImportJobsResponse
List import jobs created for a specific data store.
-
#list_image_set_versions(params = {}) ⇒ Types::ListImageSetVersionsResponse
List image set versions.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a medical imaging resource.
-
#search_image_sets(params = {}) ⇒ Types::SearchImageSetsResponse
Search image sets based on defined input attributes.
-
#start_dicom_import_job(params = {}) ⇒ Types::StartDICOMImportJobResponse
Start importing bulk data into an ‘ACTIVE` data store.
-
#tag_resource(params = {}) ⇒ Struct
Adds a user-specifed key and value tag to a medical imaging resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a medical imaging resource.
-
#update_image_set_metadata(params = {}) ⇒ Types::UpdateImageSetMetadataResponse
Update image set metadata attributes.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1457 1458 1459 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1457 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1460 1461 1462 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1460 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1430 1431 1432 1433 1434 1435 1436 1437 1438 1439 1440 1441 1442 1443 1444 1445 1446 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1430 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::MedicalImaging') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-medicalimaging' context[:gem_version] = '1.48.0' Seahorse::Client::Request.new(handlers, context) end |
#copy_image_set(params = {}) ⇒ Types::CopyImageSetResponse
Copy an image set.
549 550 551 552 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 549 def copy_image_set(params = {}, = {}) req = build_request(:copy_image_set, params) req.send_request() end |
#create_datastore(params = {}) ⇒ Types::CreateDatastoreResponse
Create a data store.
605 606 607 608 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 605 def create_datastore(params = {}, = {}) req = build_request(:create_datastore, params) req.send_request() end |
#delete_datastore(params = {}) ⇒ Types::DeleteDatastoreResponse
Delete a data store.
<note markdown=“1”> Before a data store can be deleted, you must first delete all image sets within it.
</note>
640 641 642 643 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 640 def delete_datastore(params = {}, = {}) req = build_request(:delete_datastore, params) req.send_request() end |
#delete_image_set(params = {}) ⇒ Types::DeleteImageSetResponse
Delete an image set.
678 679 680 681 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 678 def delete_image_set(params = {}, = {}) req = build_request(:delete_image_set, params) req.send_request() end |
#get_datastore(params = {}) ⇒ Types::GetDatastoreResponse
Get data store properties.
769 770 771 772 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 769 def get_datastore(params = {}, = {}) req = build_request(:get_datastore, params) req.send_request() end |
#get_dicom_import_job(params = {}) ⇒ Types::GetDICOMImportJobResponse
Get the import job properties to learn more about the job or job progress.
<note markdown=“1”> The ‘jobStatus` refers to the execution of the import job. Therefore, an import job can return a `jobStatus` as `COMPLETED` even if validation issues are discovered during the import process. If a `jobStatus` returns as `COMPLETED`, we still recommend you review the output manifests written to S3, as they provide details on the success or failure of individual P10 object imports.
</note>
733 734 735 736 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 733 def get_dicom_import_job(params = {}, = {}) req = build_request(:get_dicom_import_job, params) req.send_request() end |
#get_image_frame(params = {}) ⇒ Types::GetImageFrameResponse
Get an image frame (pixel data) for an image set.
809 810 811 812 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 809 def get_image_frame(params = {}, = {}, &block) req = build_request(:get_image_frame, params) req.send_request(, &block) end |
#get_image_set(params = {}) ⇒ Types::GetImageSetResponse
Get image set properties.
871 872 873 874 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 871 def get_image_set(params = {}, = {}) req = build_request(:get_image_set, params) req.send_request() end |
#get_image_set_metadata(params = {}) ⇒ Types::GetImageSetMetadataResponse
Get metadata attributes for an image set.
911 912 913 914 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 911 def (params = {}, = {}, &block) req = build_request(:get_image_set_metadata, params) req.send_request(, &block) end |
#list_datastores(params = {}) ⇒ Types::ListDatastoresResponse
List data stores.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1011 1012 1013 1014 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1011 def list_datastores(params = {}, = {}) req = build_request(:list_datastores, params) req.send_request() end |
#list_dicom_import_jobs(params = {}) ⇒ Types::ListDICOMImportJobsResponse
List import jobs created for a specific data store.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
964 965 966 967 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 964 def list_dicom_import_jobs(params = {}, = {}) req = build_request(:list_dicom_import_jobs, params) req.send_request() end |
#list_image_set_versions(params = {}) ⇒ Types::ListImageSetVersionsResponse
List image set versions.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1066 1067 1068 1069 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1066 def list_image_set_versions(params = {}, = {}) req = build_request(:list_image_set_versions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists all tags associated with a medical imaging resource.
1096 1097 1098 1099 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1096 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#search_image_sets(params = {}) ⇒ Types::SearchImageSetsResponse
Search image sets based on defined input attributes.
<note markdown=“1”> ‘SearchImageSets` accepts a single search query parameter and returns a paginated response of all image sets that have the matching criteria. All date range queries must be input as `(lowerBound, upperBound)`.
By default, `SearchImageSets` uses the `updatedAt` field for sorting
in descending order from newest to oldest.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1205 1206 1207 1208 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1205 def search_image_sets(params = {}, = {}) req = build_request(:search_image_sets, params) req.send_request() end |
#start_dicom_import_job(params = {}) ⇒ Types::StartDICOMImportJobResponse
Start importing bulk data into an ‘ACTIVE` data store. The import job imports DICOM P10 files or enhances existing DICOM files with JSON metadata. The `importConfiguration` parameter specifies the import type. The data is found in the S3 prefix specified by the `inputS3Uri` parameter. The import job stores processing results in the file specified by the `outputS3Uri` parameter.
1288 1289 1290 1291 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1288 def start_dicom_import_job(params = {}, = {}) req = build_request(:start_dicom_import_job, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds a user-specifed key and value tag to a medical imaging resource.
1318 1319 1320 1321 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1318 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a medical imaging resource.
1345 1346 1347 1348 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1345 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_image_set_metadata(params = {}) ⇒ Types::UpdateImageSetMetadataResponse
Update image set metadata attributes.
1421 1422 1423 1424 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1421 def (params = {}, = {}) req = build_request(:update_image_set_metadata, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1450 1451 1452 |
# File 'lib/aws-sdk-medicalimaging/client.rb', line 1450 def waiter_names [] end |