Class: Aws::MedicalImaging::Types::CopyImageSetRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::MedicalImaging::Types::CopyImageSetRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medicalimaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_image_set_information ⇒ Types::CopyImageSetInformation
Copy image set information.
-
#datastore_id ⇒ String
The data store identifier.
-
#force ⇒ Boolean
Providing this parameter will force completion of the ‘CopyImageSet` operation, even if there are inconsistent Patient, Study, and/or Series level metadata elements between the `sourceImageSet` and `destinationImageSet`.
-
#promote_to_primary ⇒ Boolean
Providing this parameter will configure the ‘CopyImageSet` operation to promote the given image set to the primary DICOM hierarchy.
-
#source_image_set_id ⇒ String
The source image set identifier.
Instance Attribute Details
#copy_image_set_information ⇒ Types::CopyImageSetInformation
Copy image set information.
167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167 class CopyImageSetRequest < Struct.new( :datastore_id, :source_image_set_id, :copy_image_set_information, :force, :promote_to_primary) SENSITIVE = [] include Aws::Structure end |
#datastore_id ⇒ String
The data store identifier.
167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167 class CopyImageSetRequest < Struct.new( :datastore_id, :source_image_set_id, :copy_image_set_information, :force, :promote_to_primary) SENSITIVE = [] include Aws::Structure end |
#force ⇒ Boolean
Providing this parameter will force completion of the ‘CopyImageSet` operation, even if there are inconsistent Patient, Study, and/or Series level metadata elements between the `sourceImageSet` and `destinationImageSet`.
167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167 class CopyImageSetRequest < Struct.new( :datastore_id, :source_image_set_id, :copy_image_set_information, :force, :promote_to_primary) SENSITIVE = [] include Aws::Structure end |
#promote_to_primary ⇒ Boolean
Providing this parameter will configure the ‘CopyImageSet` operation to promote the given image set to the primary DICOM hierarchy. If successful, a new primary image set ID will be returned as the destination image set.
167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167 class CopyImageSetRequest < Struct.new( :datastore_id, :source_image_set_id, :copy_image_set_information, :force, :promote_to_primary) SENSITIVE = [] include Aws::Structure end |
#source_image_set_id ⇒ String
The source image set identifier.
167 168 169 170 171 172 173 174 175 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 167 class CopyImageSetRequest < Struct.new( :datastore_id, :source_image_set_id, :copy_image_set_information, :force, :promote_to_primary) SENSITIVE = [] include Aws::Structure end |