Class: Aws::MedicalImaging::Types::GetImageSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::MedicalImaging::Types::GetImageSetResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-medicalimaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The timestamp when image set properties were created.
-
#datastore_id ⇒ String
The data store identifier.
-
#deleted_at ⇒ Time
The timestamp when the image set properties were deleted.
-
#image_set_arn ⇒ String
The Amazon Resource Name (ARN) assigned to the image set.
-
#image_set_id ⇒ String
The image set identifier.
-
#image_set_state ⇒ String
The image set state.
-
#image_set_workflow_status ⇒ String
The image set workflow status.
-
#is_primary ⇒ Boolean
The flag to determine whether the image set is primary or not.
-
#last_accessed_at ⇒ Time
When the image set was last accessed.
-
#message ⇒ String
The error message thrown if an image set action fails.
-
#overrides ⇒ Types::Overrides
This object contains the details of any overrides used while creating a specific image set version.
-
#storage_tier ⇒ String
The storage tier of the image set.
-
#updated_at ⇒ Time
The timestamp when image set properties were updated.
-
#version_id ⇒ String
The image set version identifier.
Instance Attribute Details
#created_at ⇒ Time
The timestamp when image set properties were created.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#datastore_id ⇒ String
The data store identifier.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#deleted_at ⇒ Time
The timestamp when the image set properties were deleted.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#image_set_arn ⇒ String
The Amazon Resource Name (ARN) assigned to the image set.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#image_set_id ⇒ String
The image set identifier.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#image_set_state ⇒ String
The image set state.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#image_set_workflow_status ⇒ String
The image set workflow status.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#is_primary ⇒ Boolean
The flag to determine whether the image set is primary or not.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#last_accessed_at ⇒ Time
When the image set was last accessed.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
The error message thrown if an image set action fails.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#overrides ⇒ Types::Overrides
This object contains the details of any overrides used while creating a specific image set version. If an image set was copied or updated using the ‘force` flag, this object will contain the `forced` flag.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#storage_tier ⇒ String
The storage tier of the image set.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The timestamp when image set properties were updated.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
The image set version identifier.
1049 1050 1051 1052 1053 1054 1055 1056 1057 1058 1059 1060 1061 1062 1063 1064 1065 1066 |
# File 'lib/aws-sdk-medicalimaging/types.rb', line 1049 class GetImageSetResponse < Struct.new( :datastore_id, :image_set_id, :version_id, :image_set_state, :image_set_workflow_status, :created_at, :updated_at, :deleted_at, :message, :image_set_arn, :overrides, :is_primary, :last_accessed_at, :storage_tier) SENSITIVE = [] include Aws::Structure end |